/** 语言信息类型 */
export type LanguageInfo = {
  /** 语言ID */
  id: string;
  /** 语言代码 */
  code: string;
  /** 语言名称 */
  name: string;
  /** 创建时间 */
  create_time: string;
  /** 更新时间 */
  update_time: string;
  /** 创建人 */
  create_by: string;
  /** 更新人 */
  update_by: string;
};
/** 翻译信息类型 */
export type TranslationInfo = {
  /** 翻译记录ID */
  id: string;
  /** 键值 */
  key: string;
  /** 翻译内容 */
  translation: string;
  /** 语言ID */
  locale_id: string;
  /** 语言代码 */
  locale_code: string;
  /** 语言名称 */
  locale_name: string;
  /** 创建时间 */
  create_time: string;
  /** 修改时间 */
  update_time: string;
  /** 创建人 */
  create_by: string;
  /** 修改人 */
  update_by: string;
};
/**部门信息类型 */
export type DepartmentInfo = {
  /**部门ID */
  id: string;
  /**状态 */
  status: number;
  /**创建时间 */
  create_time: string;
  /**修改时间 */
  update_time: string;
  /**部门名称 */
  name: string;
  /**父部门ID */
  parent_id: string;
  /**排序 */
  sort: number;
  /**部门电话 */
  phone: string;
  /**负责人 */
  principal: string;
  /**部门邮件 */
  email: string;
  /**备注信息 */
  remark: string;
};

/**权限信息类型 */
export type PermissionInfo = {
  /** 菜单ID */
  id: string;
  /** 创建人 */
  create_by: string;
  /** 创建时间 */
  create_time: string;
  /** 更新人 */
  update_by: string;
  /** 更新时间 */
  update_time: string;
  /** 菜单类型（0代表菜单、1代表按钮） */
  menu_type: number;
  /** 父菜单ID */
  parent_id: string;
  /** 菜单标题 */
  title: string;
  /** 菜单名称（用于路由名称） */
  name: string;
  /** 菜单路径 */
  path: string;
  /** 组件路径 */
  component: string;
  /** 菜单排序 */
  rank: number;
  /** 重定向路径 */
  redirect: string | null;
  /** 菜单图标 */
  icon: string;
  /** 额外图标 */
  extra_icon: string | null;
  /** 进入页面过渡动画 */
  enter_transition: string | null;
  /** 离开页面过渡动画 */
  leave_transition: string | null;
  /** 激活路径 */
  active_path: string | null;
  /** 权限标识 */
  auths: string;
  /** 内嵌框架地址 */
  frame_src: string | null;
  /** 内嵌框架加载状态 */
  frame_loading: boolean;
  /** 是否缓存页面 */
  keep_alive: boolean;
  /** 是否隐藏标签页 */
  hidden_tag: boolean;
  /** 是否固定标签页 */
  fixed_tag: boolean;
  /** 是否显示菜单链接 */
  show_link: boolean;
  /** 是否显示父菜单 */
  show_parent: boolean;
  /**是否为管理员专属页面 */
  is_admin: boolean;
};

/**角色信息类型 */
export type RoleInfo = {
  /**角色ID */
  id: string;
  /**状态 */
  status: number;
  /**创建时间 */
  create_time: string;
  /**修改时间 */
  update_time: string;
  /**部门名称 */
  name: string;
  /**角色标识符 */
  code: string;
  /**角色描述 */
  description: string;
  /**角色部门ID */
  department_id: string;
};

/** 角色权限关联信息类型 */
export type RolePermissionInfo = {
  /** 主键ID */
  id: string;
  /** 创建人 */
  create_by: string;
  /** 创建时间 */
  create_time: string;
  /** 更新人 */
  update_by: string;
  /** 更新时间 */
  update_time: string;
  /** 角色ID */
  role_id: string;
  /** 角色名称 */
  role_name: string;
  /** 角色编码 */
  role_code: string;
  /** 权限ID */
  permission_id: string;
  /**
   * 权限父ID
   */
  permission_parent_id: string;
  /** 权限名称 */
  permission_name: string;
  /** 权限编码 */
  permission_code: string;
  /** 权限类型 */
  permission_type: string;
};

/**用户信息类型 */
export type UserInfo = {
  /**用户名 */
  username: string;
  /**用户昵称 */
  nickname: string;
  /**用户状态 */
  status: number;
  /**用户性别 */
  gender: number;
  /**用户头像 */
  avatar: string;
  /**用户数据库ID */
  id: string;
  /**用户邮箱 */
  email: string;
  /**用户手机号 */
  phone: string;
  /**创建时间 */
  create_time: string;
  /**修改时间 */
  update_time: string;
  /**部门ID */
  department_id: string;
};
/** 部门角色关联信息类型 */
export type DepartmentRoleInfo = {
  /** 主键ID */
  id: string;
  /** 部门ID */
  department_id: string;
  /** 部门名称 */
  department_name: string;
  /** 部门电话 */
  department_phone: string;
  /** 部门负责人 */
  department_principal: string;
  /** 部门邮箱 */
  department_email: string;
  /** 角色名称 */
  role_name: string;
  /** 角色编码 */
  role_code: string;
  /** 角色ID */
  role_id: string;
  /** 创建时间 */
  create_time: string;
  /** 更新时间 */
  update_time: string;
};

/**系统配置信息 */
export interface ConfigInfo {
  /** 主键ID */
  id: string;
  /** 创建人 */
  create_by: string;
  /** 创建时间 */
  create_time: string;
  /** 更新人 */
  update_by: string;
  /** 更新时间 */
  update_time: string;
  /**配置名称 */
  name: string;
  /**配置键 */
  key: string;
  /**配置值 */
  value: string;
  /**系统配置 */
  type: boolean;
  /**备注 */
  remark: string;
}
